@@ -54,6 +54,7 @@ class DbManagerMongo:
         self.stats_company_collection = self._db.get_collection("stats_company")
         self.stats_nace_collection = self._db.get_collection("stats_nace")
         self.stats_decision_makers_collection = self._db.get_collection("stats_decision_makers")
+        self.stats_decision_makers_departments_collection = self._db.get_collection("stats_decision_makers_departments")
 
         # Internal utils Collections
         self.do_not_call_me_collection = self._db.get_collection("do_not_call_me")
@@ -61,6 +62,7 @@ class DbManagerMongo:
         self.delivery_memory_collection = self._db.get_collection("delivery_memory")
         self.api_users_collection = self._db.get_collection("api_users")
         self.kaspr_cache_collection = self._db.get_collection("kaspr_cache")
+        self.nace_collection = self._db.get_collection("nace_codes")
 
         # Legacy collections
         self.company_keywords = self._db.get_collection("company_keywords")
@@ -139,10 +141,25 @@ class DbManagerMongo:
             [("description_id", ASCENDING)],
             [("description_id", ASCENDING), ("country", ASCENDING)],
             # For Inoopa NACE filtering (used in nace_code_correction)
+            [("best_nace_codes.first_best_nace_code.number", 1)],
             [("nace_codes", ASCENDING)],
+            [("establishments.nace_codes.number", 1)],
+            [("nace_codes.number", ASCENDING)],
             [("nace_codes.source", ASCENDING)],
             [("country", ASCENDING), ("nace_codes", ASCENDING)],
             [("country", ASCENDING), ("nace_codes.source", ASCENDING)],
+            # For Orange deliveries
+            [
+                ("country", 1),
+                ("status", 1),
+                ("legal_situation", 1),
+                ("legal_form_type", 1),
+                ("address.region", 1),
+                ("employee_category_code", 1),
+                ("best_phone.operator_last_update", 1),
+                ("best_phone.operator", 1),
+                ("best_phone.phone", 1),
+            ],
         ]
         fields_to_index_website_structure = [
             [("_id", ASCENDING)],  # Base url
@@ -175,6 +192,11 @@ class DbManagerMongo:
             [("date", DESCENDING)],
             [("country", ASCENDING)],
         ]
+        fields_to_index_nace_codes = [
+            [("number", ASCENDING)],
+            [("section_code", ASCENDING)],
+            [("source", ASCENDING)],
+        ]
         self._logger.info("Creating indexes in collections (if not created yet)...")
         self._logger.info(
             "If this takes time (~10 mins), the indexes are not created yet. You will get a message when it's done."
@@ -192,6 +214,7 @@ class DbManagerMongo:
             {self.stats_company_collection: fields_to_index_stats},
             {self.stats_decision_makers_collection: fields_to_index_stats},
             {self.stats_nace_collection: fields_to_index_stats},
+            {self.nace_collection: fields_to_index_nace_codes},
         ]
 
         for indexer in collections_to_index:
@@ -479,5 +502,4 @@ def enrich_companies_dicts_with_decision_makers(
 
 
 if __name__ == "__main__":
-    os.environ["ENV"] = "prod"
     db_manager = DbManagerMongo(create_index_if_not_done=True)
