@@ -1,19 +1,17 @@
+import os
 import time
 from datetime import datetime
-
-from dotenv import load_dotenv
-
-load_dotenv()
-
-import os
 from typing import cast
 
 import requests
+from dotenv import load_dotenv
 from typesense.client import Client as TypesenseClient
 from typesense.collection import Collection
 
 from inoopa_utils.inoopa_logging import create_logger
 
+load_dotenv()
+
 EMBEDDING_MODEL = "text-embedding-3-small"
 EMBEDDING_MODEL_EXPENSIVE = "text-embedding-3-large"
 EMBEDDING_CONTEXT_MAX_LENGTH = 8191
@@ -21,7 +19,7 @@ EMBEDDING_ENCODING = "cl100k_base"
 # For the model name to typesense's namming convention
 EMBEDDING_MODEL_TYPESENSE_NAME = f"openai/{EMBEDDING_MODEL}"
 EXPENSIVE_EMBEDDING_MODEL_TYPESENSE_NAME = f"openai/{EMBEDDING_MODEL_EXPENSIVE}"
-OPENAI_API_KEY = os.environ["OPENAI_API_KEY"]
+OPENAI_API_KEY = os.getenv("OPENAI_API_KEY")
 
 
 class TypesenseManager:
@@ -41,9 +39,9 @@ class TypesenseManager:
 
     def __init__(
         self,
-        host: str = os.environ["TYPESENSE_HOST"],
+        host: str = os.getenv("TYPESENSE_HOST", ""),
         port: int = int(os.getenv("TYPESENSE_PORT", 443)),  # Default port is 443 for HTTPS
-        api_key: str = os.environ["TYPESENSE_API_KEY"],
+        api_key: str = os.getenv("TYPESENSE_API_KEY", ""),
         protocol: str = "https",
         pretty_logging: bool = False,
     ):
